# -*- coding: utf-8 -*-
# (c) 2012 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com

"""
Bright Interactive Version Control

Based on Semantic Versioning (http://semver.org/) but simpler - only "normal"
(X.Y.Z) versions are allowed, not pre-release (1.0.0-alpha.1) or build
(1.0.0+build.1) versions.
"""

import re


# Version number of the bright_vc package 
__version__ = '1.1.0'


# Constants
VERSION_PATTERN = """[0-9]+\.[0-9]+\.[0-9]+((a|b|pr)[0-9]+)?$"""
VERSION_RE = re.compile(VERSION_PATTERN)
TAG_RE = re.compile("""v""" + VERSION_PATTERN)


def check_tag(tag_name):
    """
    Check that tag_name is a valid tag name and raise an exception if not.
    """
    if not TAG_RE.match(tag_name):
        raise Exception("%s is not a valid tag name" % tag_name)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# (c) 2012 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com

import os.path
import sys
# put parent dir on sys.path so that "import bright_vc" will work
sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

import bright_vc
import unittest


class TagCheckTests(unittest.TestCase):
    def test_valid_tag_accepted(self):
        bright_vc.check_tag("v10.20.30")
        bright_vc.check_tag("v10.20.30a1")
        bright_vc.check_tag("v10.20.30a10")
        bright_vc.check_tag("v10.20.30b100")
        bright_vc.check_tag("v1.0.1pr5")
        bright_vc.check_tag("v0.1.0pr5000")

    def test_invalid_tag_not_accepted(self):
        self.assertRaises(Exception, bright_vc.check_tag, "v10.20.30-a")
        self.assertRaises(Exception, bright_vc.check_tag, "v10.0.b")
        self.assertRaises(Exception, bright_vc.check_tag, "v10.c.30")
        self.assertRaises(Exception, bright_vc.check_tag, "vd.1.30")
        self.assertRaises(Exception, bright_vc.check_tag, "v1.1.1p")
        self.assertRaises(Exception, bright_vc.check_tag, "v1.1.1r")
        self.assertRaises(Exception, bright_vc.check_tag, "v1.1.1a")
        self.assertRaises(Exception, bright_vc.check_tag, "v1.1.1ba")


if __name__ == '__main__':
    unittest.main()
